package Bundle::Locale::CLDR::Easternafrica;

use version;

our $VERSION = version->declare('v0.34.1');

=head1 NAME Bundle::Locale::CLDR::Easternafrica

=head1 CONTENTS

Locale::CLDR::Locales::Am 0.34.1
Locale::CLDR::Locales::Ar 0.34.1
Locale::CLDR::Locales::Fr 0.34.1
Locale::CLDR::Locales::Ki 0.34.1
Locale::CLDR::Locales::Lg 0.34.1
Locale::CLDR::Locales::Mg 0.34.1
Locale::CLDR::Locales::Nd 0.34.1
Locale::CLDR::Locales::Om 0.34.1
Locale::CLDR::Locales::Pt 0.34.1
Locale::CLDR::Locales::Rn 0.34.1
Locale::CLDR::Locales::Rw 0.34.1
Locale::CLDR::Locales::Sn 0.34.1
Locale::CLDR::Locales::So 0.34.1
Locale::CLDR::Locales::Sw 0.34.1
Locale::CLDR::Locales::Ti 0.34.1
Locale::CLDR::Locales::Asa 0.34.1
Locale::CLDR::Locales::Bem 0.34.1
Locale::CLDR::Locales::Bez 0.34.1
Locale::CLDR::Locales::Cgg 0.34.1
Locale::CLDR::Locales::Dav 0.34.1
Locale::CLDR::Locales::Ebu 0.34.1
Locale::CLDR::Locales::Guz 0.34.1
Locale::CLDR::Locales::Jmc 0.34.1
Locale::CLDR::Locales::Kam 0.34.1
Locale::CLDR::Locales::Kde 0.34.1
Locale::CLDR::Locales::Kln 0.34.1
Locale::CLDR::Locales::Ksb 0.34.1
Locale::CLDR::Locales::Lag 0.34.1
Locale::CLDR::Locales::Luo 0.34.1
Locale::CLDR::Locales::Luy 0.34.1
Locale::CLDR::Locales::Mas 0.34.1
Locale::CLDR::Locales::Mer 0.34.1
Locale::CLDR::Locales::Mfe 0.34.1
Locale::CLDR::Locales::Mgh 0.34.1
Locale::CLDR::Locales::Nus 0.34.1
Locale::CLDR::Locales::Nyn 0.34.1
Locale::CLDR::Locales::Rof 0.34.1
Locale::CLDR::Locales::Rwk 0.34.1
Locale::CLDR::Locales::Saq 0.34.1
Locale::CLDR::Locales::Sbp 0.34.1
Locale::CLDR::Locales::Seh 0.34.1
Locale::CLDR::Locales::Teo 0.34.1
Locale::CLDR::Locales::Vun 0.34.1
Locale::CLDR::Locales::Xog 0.34.1
Locale::CLDR::Locales::Am::Any 0.34.1
Locale::CLDR::Locales::Ar::Any 0.34.1
Locale::CLDR::Locales::En::Any 0.34.1
Locale::CLDR::Locales::Fr::Any 0.34.1
Locale::CLDR::Locales::Ki::Any 0.34.1
Locale::CLDR::Locales::Lg::Any 0.34.1
Locale::CLDR::Locales::Mg::Any 0.34.1
Locale::CLDR::Locales::Nd::Any 0.34.1
Locale::CLDR::Locales::Om::Any 0.34.1
Locale::CLDR::Locales::Pt::Any 0.34.1
Locale::CLDR::Locales::Rn::Any 0.34.1
Locale::CLDR::Locales::Rw::Any 0.34.1
Locale::CLDR::Locales::Sn::Any 0.34.1
Locale::CLDR::Locales::So::Any 0.34.1
Locale::CLDR::Locales::Sw::Any 0.34.1
Locale::CLDR::Locales::Ti::Any 0.34.1
Locale::CLDR::Locales::Asa::Any 0.34.1
Locale::CLDR::Locales::Bem::Any 0.34.1
Locale::CLDR::Locales::Bez::Any 0.34.1
Locale::CLDR::Locales::Cgg::Any 0.34.1
Locale::CLDR::Locales::Dav::Any 0.34.1
Locale::CLDR::Locales::Ebu::Any 0.34.1
Locale::CLDR::Locales::Guz::Any 0.34.1
Locale::CLDR::Locales::Jmc::Any 0.34.1
Locale::CLDR::Locales::Kam::Any 0.34.1
Locale::CLDR::Locales::Kde::Any 0.34.1
Locale::CLDR::Locales::Kln::Any 0.34.1
Locale::CLDR::Locales::Ksb::Any 0.34.1
Locale::CLDR::Locales::Lag::Any 0.34.1
Locale::CLDR::Locales::Luo::Any 0.34.1
Locale::CLDR::Locales::Luy::Any 0.34.1
Locale::CLDR::Locales::Mas::Any 0.34.1
Locale::CLDR::Locales::Mer::Any 0.34.1
Locale::CLDR::Locales::Mfe::Any 0.34.1
Locale::CLDR::Locales::Mgh::Any 0.34.1
Locale::CLDR::Locales::Nus::Any 0.34.1
Locale::CLDR::Locales::Nyn::Any 0.34.1
Locale::CLDR::Locales::Rof::Any 0.34.1
Locale::CLDR::Locales::Rwk::Any 0.34.1
Locale::CLDR::Locales::Saq::Any 0.34.1
Locale::CLDR::Locales::Sbp::Any 0.34.1
Locale::CLDR::Locales::Seh::Any 0.34.1
Locale::CLDR::Locales::Teo::Any 0.34.1
Locale::CLDR::Locales::Vun::Any 0.34.1
Locale::CLDR::Locales::Xog::Any 0.34.1
Locale::CLDR::Locales::Am::Any::Et 0.34.1
Locale::CLDR::Locales::Ar::Any::Dj 0.34.1
Locale::CLDR::Locales::Ar::Any::Er 0.34.1
Locale::CLDR::Locales::Ar::Any::Km 0.34.1
Locale::CLDR::Locales::Ar::Any::So 0.34.1
Locale::CLDR::Locales::Ar::Any::Ss 0.34.1
Locale::CLDR::Locales::En::Any::Bi 0.34.1
Locale::CLDR::Locales::En::Any::Er 0.34.1
Locale::CLDR::Locales::En::Any::Io 0.34.1
Locale::CLDR::Locales::En::Any::Ke 0.34.1
Locale::CLDR::Locales::En::Any::Mg 0.34.1
Locale::CLDR::Locales::En::Any::Mu 0.34.1
Locale::CLDR::Locales::En::Any::Mw 0.34.1
Locale::CLDR::Locales::En::Any::Rw 0.34.1
Locale::CLDR::Locales::En::Any::Sc 0.34.1
Locale::CLDR::Locales::En::Any::Ss 0.34.1
Locale::CLDR::Locales::En::Any::Tz 0.34.1
Locale::CLDR::Locales::En::Any::Ug 0.34.1
Locale::CLDR::Locales::En::Any::Zm 0.34.1
Locale::CLDR::Locales::En::Any::Zw 0.34.1
Locale::CLDR::Locales::Fr::Any::Bi 0.34.1
Locale::CLDR::Locales::Fr::Any::Dj 0.34.1
Locale::CLDR::Locales::Fr::Any::Km 0.34.1
Locale::CLDR::Locales::Fr::Any::Mg 0.34.1
Locale::CLDR::Locales::Fr::Any::Mu 0.34.1
Locale::CLDR::Locales::Fr::Any::Re 0.34.1
Locale::CLDR::Locales::Fr::Any::Rw 0.34.1
Locale::CLDR::Locales::Fr::Any::Sc 0.34.1
Locale::CLDR::Locales::Fr::Any::Yt 0.34.1
Locale::CLDR::Locales::Ki::Any::Ke 0.34.1
Locale::CLDR::Locales::Lg::Any::Ug 0.34.1
Locale::CLDR::Locales::Mg::Any::Mg 0.34.1
Locale::CLDR::Locales::Nd::Any::Zw 0.34.1
Locale::CLDR::Locales::Om::Any::Et 0.34.1
Locale::CLDR::Locales::Om::Any::Ke 0.34.1
Locale::CLDR::Locales::Pt::Any::Mz 0.34.1
Locale::CLDR::Locales::Pt::Any::Pt 0.34.1
Locale::CLDR::Locales::Rn::Any::Bi 0.34.1
Locale::CLDR::Locales::Rw::Any::Rw 0.34.1
Locale::CLDR::Locales::Sn::Any::Zw 0.34.1
Locale::CLDR::Locales::So::Any::Dj 0.34.1
Locale::CLDR::Locales::So::Any::Et 0.34.1
Locale::CLDR::Locales::So::Any::Ke 0.34.1
Locale::CLDR::Locales::So::Any::So 0.34.1
Locale::CLDR::Locales::Sw::Any::Ke 0.34.1
Locale::CLDR::Locales::Sw::Any::Tz 0.34.1
Locale::CLDR::Locales::Sw::Any::Ug 0.34.1
Locale::CLDR::Locales::Ti::Any::Er 0.34.1
Locale::CLDR::Locales::Ti::Any::Et 0.34.1
Locale::CLDR::Locales::Asa::Any::Tz 0.34.1
Locale::CLDR::Locales::Bem::Any::Zm 0.34.1
Locale::CLDR::Locales::Bez::Any::Tz 0.34.1
Locale::CLDR::Locales::Cgg::Any::Ug 0.34.1
Locale::CLDR::Locales::Dav::Any::Ke 0.34.1
Locale::CLDR::Locales::Ebu::Any::Ke 0.34.1
Locale::CLDR::Locales::En::Any::001 0.34.1
Locale::CLDR::Locales::Guz::Any::Ke 0.34.1
Locale::CLDR::Locales::Jmc::Any::Tz 0.34.1
Locale::CLDR::Locales::Kam::Any::Ke 0.34.1
Locale::CLDR::Locales::Kde::Any::Tz 0.34.1
Locale::CLDR::Locales::Kln::Any::Ke 0.34.1
Locale::CLDR::Locales::Ksb::Any::Tz 0.34.1
Locale::CLDR::Locales::Lag::Any::Tz 0.34.1
Locale::CLDR::Locales::Luo::Any::Ke 0.34.1
Locale::CLDR::Locales::Luy::Any::Ke 0.34.1
Locale::CLDR::Locales::Mas::Any::Ke 0.34.1
Locale::CLDR::Locales::Mas::Any::Tz 0.34.1
Locale::CLDR::Locales::Mer::Any::Ke 0.34.1
Locale::CLDR::Locales::Mfe::Any::Mu 0.34.1
Locale::CLDR::Locales::Mgh::Any::Mz 0.34.1
Locale::CLDR::Locales::Nus::Any::Ss 0.34.1
Locale::CLDR::Locales::Nyn::Any::Ug 0.34.1
Locale::CLDR::Locales::Rof::Any::Tz 0.34.1
Locale::CLDR::Locales::Rwk::Any::Tz 0.34.1
Locale::CLDR::Locales::Saq::Any::Ke 0.34.1
Locale::CLDR::Locales::Sbp::Any::Tz 0.34.1
Locale::CLDR::Locales::Seh::Any::Mz 0.34.1
Locale::CLDR::Locales::Teo::Any::Ke 0.34.1
Locale::CLDR::Locales::Teo::Any::Ug 0.34.1
Locale::CLDR::Locales::Vun::Any::Tz 0.34.1
Locale::CLDR::Locales::Xog::Any::Ug 0.34.1

=cut

1;

